@@ -22,6 +22,11 @@ test_that("auc returns correctly with xlim", {
   expect_equal(auc(x = 1:10, y = (1:10)**2, xlim = c(2, NA)), 332)
   expect_equal(auc(x = 1:10, y = (1:10)**2, xlim = c(NA, 7)), 115)
   expect_error(auc(x = 1:10, y = (1:10)**2, xlim = c(NA, NA)))
+  expect_warning(auc(x = 2:8, y = (2:8)**2, xlim = c(1, 8)),
+                 "xlim specifies lower limit below the range of x")
+  expect_warning(auc(x = 2:8, y = (2:8)**2, xlim = c(2, 9)),
+                 "xlim specifies upper limit above the range of x")
+  expect_equal(auc(x = 1:10, y = c(NA, (2:9)**2, NA), xlim = c(1, 10)), 241.5)
 })
 
 test_that("lag_time returns correctly", {
@@ -46,8 +51,10 @@ test_that("lag_time returns correctly", {
   y1 <- dat$y[which.max(dat$deriv)]
   x1 <- dat$x[which.max(dat$deriv)]
   m <- max(dat$deriv, na.rm = TRUE)
-  lag <- lag_time(slope = m, y0 = y0, x1 = x1, y1 = y1)
-  expect_equal(log(y1) - m*x1 + m*lag, log(y0))
+  lag <- lag_time(slope = m, y0 = y0, x1 = x1, y1 = y1, blank = 0)
+  expect_equal(lag, (log(y0) - log(y1))/m + x1)
+  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, blank = 0),
+               (log(y0) - log(y1))/m + x1)
   if(F) {
     plot(dat$x, log(dat$y))
     points(x1, log(y1), col = "red")
@@ -58,50 +65,122 @@ test_that("lag_time returns correctly", {
     abline(h = m)
   }
   
-  #Data has lots of NA's
+  #blank is non-zero
+  dat <- mutate(group_by(dat, grp),
+                y2 = y + 0.2,
+                deriv = calc_deriv(y = y2, x = x, percapita = TRUE, 
+                                   blank = 0.2, trans_y = "log", 
+                                   window_width_n = 5))
+  y0 <- min(dat$y2, na.rm = TRUE)
+  y1 <- dat$y2[which.max(dat$deriv)]
+  x1 <- dat$x[which.max(dat$deriv)]
+  m <- max(dat$deriv, na.rm = TRUE)
+  lag <- lag_time(slope = m, y0 = y0, x1 = x1, y1 = y1, blank = 0.2)
+  expect_equal(lag, (log(y0 - 0.2) - log(y1 - 0.2))/m + x1)
+  expect_equal(lag_time(x = dat$x, y = dat$y2, deriv = dat$deriv, blank = 0.2),
+               (log(y0 - 0.2) - log(y1 - 0.2))/m + x1)
+  if(F) {
+    plot(dat$x, log(dat$y2 - 0.2))
+    points(x1, log(y1 - 0.2), col = "red")
+    abline(a = log(y1 - 0.2) - m*x1, b = m)
+    abline(h = log(y0 - 0.2), lty = 2)
+    abline(v = lag, lty = 2)
+    plot(dat$x, dat$deriv)
+    abline(h = m)
+  }
+  
+  #blank is not provided
+  expect_error(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv),
+               "blank must be provided when trans_y = 'log'")
+               
+  #blank is provided but is the wrong length
+  expect_warning(
+    lag_time(x = dat$x, y = dat$y2, deriv = dat$deriv, blank = c(0.2, 0.1)),
+    "Multiple blank values provided, only using the first for normalizing 'y'")
+  expect_warning(
+    expect_warning(
+      lag_time(slope = m, y0 = y0, x1 = x1, y1 = y1, blank = c(0.2, 0.1)),
+      "Number of blank values not the same as number of"),
+    "Number of blank values not the same as number of")
+                 
+  #y data has lots of NA's
   dat <- data.frame(x = 1:100, y = (-10):89, grp = rep("A", 100))
   dat <- mutate(group_by(dat, grp), 
                 deriv = calc_deriv(x = x, y = y, percapita = TRUE, blank = 0))
   expect_warning(expect_warning(
-    lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv),
+    lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, blank = 0),
     "NaNs produced"),
     "infinite values")
   expect_equal(lag, 12)
   
-  #Data is nearly all NAs
+  #y data is nearly all NAs
   dat <- data.frame(x = 1:10, y = c(1, rep(NA, 8), 100), grp = rep("A", 10))
   dat <- mutate(group_by(dat, grp), 
                 deriv = calc_deriv(x = x, y = y, percapita = TRUE, blank = 0))
-  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv),
-               NA)
+  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, blank = 0),
+               1)
   dat <- data.frame(x = 1:10, y = c(1, rep(NA, 7), 81, 100), grp = rep("A", 10))
   dat <- mutate(group_by(dat, grp), 
                 deriv = calc_deriv(x = x, y = y, percapita = TRUE, blank = 0))
-  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv),
+  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, blank = 0),
                1)
   
-  #Data is all NAs
+  #y data is all NAs
   dat <- data.frame(x = 1:10, y = rep(NA, 10), deriv = 1:10)
-  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv),
-               NA)
+  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, blank = 0),
+               as.numeric(NA))
   
   #All y values are 0
   dat <- data.frame(x = 1:10, y = rep(0, 10), deriv = 1:10)
-  expect_warning(lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv),
+  expect_warning(lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, 
+                                 blank = 0),
                  "infinite values created")
-  expect_equal(lag, NA)
+  expect_equal(lag, as.numeric(NA))
   
   #All deriv are 0
   dat <- data.frame(x = 1:10, y = 1:10, deriv = rep(0, 10))
-  expect_warning(lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv),
+  expect_warning(lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, 
+                                 blank = 0),
                  "multiple timepoints have")
   expect_equal(lag, NaN)
   
   #All deriv are the same (so matches the first one with warning)
   dat <- data.frame(x = 1:10, y = 1:10, deriv = rep(5, 10))
-  expect_warning(lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv),
+  expect_warning(lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, 
+                                 blank = 0),
                  "multiple timepoints have")
   expect_equal(lag, 1)
+  
+  #Deriv has NA values where min(y) is
+  dat <- data.frame(x = 1:10, y = exp(1:10), deriv = c(NA, 1, rep(0.9, 8)))
+  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, blank = 0), 1)
+  
+  #min(y) occurs where x is NA
+  dat <- data.frame(x = c(NA, 2:10), y = exp(1:10), deriv = 1:10)
+  expect_warning(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, blank = 0),
+                 regexp = "min\\(y\\) does not equal min")
+  
+  #lag time is less than min(x)
+  dat <- data.frame(x = 1:10, y = exp(1:10), deriv = c(NA, 0.5, rep(0.1, 8)))
+  expect_warning(lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, 
+                                 blank = 0),
+                 regexp = "indicating no identifiable lag phase")
+  expect_equal(lag, 0)
+  
+  #lag time is less than min(x[!is.na(y)])
+  dat <- data.frame(x = 1:10, y = c(NA, exp(2:10)), 
+                    deriv = c(NA, NA, 0.8, rep(0.1, 7)))
+  expect_warning(lag <- lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, 
+                                 blank = 0),
+                 regexp = "indicating no identifiable lag phase")
+  expect_equal(lag, 1.75)
+  
+  #na.rm = FALSE
+  dat <- data.frame(x = 1:10, y = c(NA, exp(2:10)), 
+                    deriv = c(NA, NA, 0.8, rep(0.1, 7)))
+  expect_equal(lag_time(x = dat$x, y = dat$y, deriv = dat$deriv, na.rm = FALSE, 
+                        blank = 0),
+               as.numeric(NA))
 })
 
 test_that("doubling_time returns correctly", {
@@ -150,12 +229,18 @@ test_that("find_local_extrema works correctly", {
   expect_equal(find_local_extrema(y = dat$y, return_minima = FALSE,
                                   window_width_n = 5),
                c(2, 12))
+  expect_equal(find_local_extrema(y = dat$y, return_minima = FALSE,
+                                  window_width_n_frac = 0.25),
+               c(2, 12))
   expect_equal(find_local_extrema(y = dat$y, return_minima = FALSE,
                                   window_height = 3),
                c(2, 12))
   expect_equal(find_local_extrema(y = dat$y, return_minima = FALSE,
                                   window_width_n = 13),
                12)
+  expect_equal(find_local_extrema(y = dat$y, return_minima = FALSE,
+                                  window_width_n_frac = 13/nrow(dat)),
+               12)
   expect_equal(find_local_extrema(y = dat$y, return_minima = FALSE,
                                   window_height = 5),
                12)
@@ -165,12 +250,18 @@ test_that("find_local_extrema works correctly", {
   expect_equal(find_local_extrema(x = dat$x, y = dat$y, return_minima = FALSE,
                                   window_width_n = 5),
                c(9, 19))
+  expect_equal(find_local_extrema(x = dat$x, y = dat$y, return_minima = FALSE,
+                                  window_width_n_frac = 5/nrow(dat)),
+               c(9, 19))
   expect_equal(find_local_extrema(x = dat$x, y = dat$y, return_minima = FALSE,
                                   window_height = 3),
                c(9, 19))
   expect_equal(find_local_extrema(x = dat$x, y = dat$y, return_minima = FALSE,
                                   window_width_n = 13),
                19)
+  expect_equal(find_local_extrema(x = dat$x, y = dat$y, return_minima = FALSE,
+                                  window_width_n_frac = 13/nrow(dat)),
+               19)
   expect_equal(find_local_extrema(x = dat$x, y = dat$y, return_minima = FALSE,
                                   window_height = 5),
                19)
@@ -352,3 +443,51 @@ test_that("find_threshold_crosses works correctly", {
     y = c(5:1, 1:5), subset = c(rep(F, 3), rep(T, 7)), threshold = 3.5), c(4, 9))
 })
 
+test_that("centroid works correctly", {
+  # #Code to plot centroids
+  # x <- 2:4
+  # y <- (2:4)*2
+  # mypoly <- sf::st_polygon(
+  #   x = list(matrix(
+  #     ncol = 2,
+  #     data = c(
+  #       #xvals
+  #       x[c(1, 1:length(x), length(x), 1)],
+  #       #yvals
+  #       c(0, y[1:length(y)], 0, 0)))))
+  # 
+  # centroid_vals <-
+  #   as.vector(sf::st_centroid(mypoly))
+  # 
+  # ggplot(data = mypoly) +
+  #   geom_sf(fill = "red") +
+  #   geom_point(aes(x = centroid_vals[1], y = centroid_vals[2]))
+  
+  expect_equal(centroid_both(x = 0:9, y = (0:9)*2),
+               c((0+9+9)/3, (0+18+0)/3))
+  
+  set.seed(1)
+  x <- 1:50
+  y <- 1 + rnorm(n = 50)
+  expect_equal(centroid_both(x = x, y = y, warn_negative_y = FALSE),
+               c(25.031003, 0.75910186),
+               tolerance = 0.0001)
+  
+  #with xlim specified
+  expect_equal(centroid_both(x = x, y = y, warn_negative_y = FALSE,
+                             xlim = c(25, 35)),
+               c(30.1640277, 0.6943426),
+               tolerance = 0.0001)
+  
+  #with blank specified
+  expect_equal(centroid_both(x = x, y = y, warn_negative_y = FALSE,
+                             blank = 0.1),
+               c(24.9840982, 0.8300192),
+               tolerance = 0.0001)
+  
+  #with neg.rm = TRUE
+  expect_equal(centroid_both(x = x, y = y, neg.rm = TRUE),
+               c(24.8683458, 0.7221994),
+               tolerance = 0.0001)
+})
+
