@@ -306,4 +306,112 @@ test_that("smooth_data checks for grouping", {
                            sm = smooth_data(window_width_n = 5, x = x, y = y, 
                                             sm_method = 'moving-median')))
 })
-  
\ No newline at end of file
+  
+test_that("predict_interpolation works correctly", {
+  x <- 1:10
+  y <- x**2
+  
+  expect_equal(predict_interpolation(x = x, y = y, newdata = c(2.5, 6.5)),
+               c(6.5, 42.5))
+  expect_equal(predict_interpolation(x = x, y = y, newdata = c(3, 5, 7)),
+               c(3, 5, 7)**2)
+  expect_equal(predict_interpolation(x = x, y = y, newdata = 0,
+                                      extrapolate_predictions = FALSE),
+               as.numeric(NA))
+  expect_equal(predict_interpolation(x = x, y = y, newdata = 15,
+                                      extrapolate_predictions = FALSE),
+               as.numeric(NA))
+  expect_equal(predict_interpolation(x = x, y = y, newdata = c(2.5, 5, 15),
+                                      extrapolate_predictions = FALSE),
+               c(6.5, 25, as.numeric(NA)))
+  expect_equal(predict_interpolation(x = x, y = y, newdata = c(0, 11)),
+               c(-2, 119))
+  expect_equal(predict_interpolation(x = x, y = y, newdata = c(0, 0.5, 10.5, 11)),
+               c(-2, -0.5, 109.5, 119))
+})
+
+test_that("train_smooth_data and train + makemethod_train_smooth_data match", {
+  library(dplyr)
+  library(caret)
+  dat <- trans_wide_to_tidy(example_widedata, id_cols = "Time")
+
+  ##Note: these tests were commented out because I didn't want to
+  ## figure out how to set defaults that wouldn't raise warnings
+  ## for having too small of spans
+  # #Default conditions
+  # for (mymethod in c("moving-average", "moving-median", "loess",
+  #                    "gam", "smooth.spline")) {
+  #   expect_equal(
+  #     reframe(group_by(filter(dat, Well %in% c("A1", "A7")), Well),
+  #             train = train_smooth_data(
+  #               x = Time, y = Measurements,
+  #               sm_method = mymethod,
+  #               trControl = caret::trainControl(
+  #                 method = "cv",
+  #                 seeds = c(rep(list(c(1,1,1)), 26), 1)))),
+  #     reframe(group_by(filter(dat, Well %in% c("A1", "A7")), Well),
+  #             train = caret::train(
+  #               x = data.frame(x = Time), y = Measurements,
+  #               method = makemethod_train_smooth_data(sm_method = mymethod),
+  #               trControl = caret::trainControl(
+  #                 method = "cv",
+  #                 seeds = c(rep(list(c(1,1,1)), 26), 1)))$results)
+  #   )
+  # }
+
+  # #Specifying length
+  # for (mymethod in c("moving-average", "moving-median", "loess",
+  #                    "gam", "smooth.spline")) {
+  #   expect_equal(
+  #     reframe(group_by(filter(dat, Well %in% c("A1", "A7")), Well),
+  #             train = train_smooth_data(
+  #               x = Time, y = Measurements,
+  #               sm_method = mymethod, tuneLength = 5,
+  #               trControl = caret::trainControl(
+  #                 method = "cv",
+  #                 seeds = c(rep(list(c(1,1,1,1,1)), 26), 1)))),
+  #     reframe(group_by(filter(dat, Well %in% c("A1", "A7")), Well),
+  #             train = caret::train(
+  #               x = data.frame(x = Time), y = Measurements,
+  #               method = makemethod_train_smooth_data(sm_method = mymethod),
+  #               tuneLength = 5,
+  #               trControl = caret::trainControl(
+  #                 method = "cv",
+  #                 seeds = c(rep(list(c(1,1,1,1,1)), 26), 1)))$results)
+  #   )
+  # }
+
+  methods <- c("moving-average", "moving-median", "loess",
+               "gam", "smooth.spline")
+  tuneGrids_list <- list(list("window_width_frac" = c(0.2, 0.4)),
+                         list("window_width_frac" = c(0.2, 0.4)),
+                         list("span" = c(0.5, 0.6)),
+                         list("k" = c(7, 9)),
+                         list("spar" = c(0.25, 0.5)))
+  #Specifying parameter values
+  for (i in 1:length(methods)) {
+    mymethod <- methods[i]
+    mytuneGrid <- tuneGrids_list[[i]]
+    set.seed(1)
+    actual <- reframe(group_by(filter(dat, Well %in% c("A1", "A7")), Well),
+                      train = train_smooth_data(
+                        x = Time, y = Measurements,
+                        sm_method = mymethod,
+                        tuneGrid = mytuneGrid,
+                        trControl = caret::trainControl(
+                          method = "cv",
+                          seeds = c(rep(list(c(1,1,1)), 26), 1))))
+    set.seed(1)
+    expected <- reframe(group_by(filter(dat, Well %in% c("A1", "A7")), Well),
+                        train = caret::train(
+                          x = data.frame(x = Time), y = Measurements,
+                          method = makemethod_train_smooth_data(
+                            sm_method = mymethod, tuneGrid = as.data.frame(mytuneGrid)),
+                          tuneGrid = as.data.frame(mytuneGrid),
+                          trControl = caret::trainControl(
+                            method = "cv",
+                            seeds = c(rep(list(c(1,1,1)), 26), 1)))$results)
+    
+    expect_equal(actual, expected)
+  }
+})
